# ReviewType: Blank

The *blank* ReviewType is primarily used for simulations.

Note: This document is currently under development. It will contain the following elements.

## Short summary

- explanation
- goals
- dimensions
- differences between disciplines

## Steps and operations

### Problem formulation

### Metadata retrieval

### Metadata prescreen

### PDF retrieval

### PDF screen

### Data extraction and synthesis

## Software recommendations

## References
